@@ -21,7 +21,7 @@ please make any changes there.
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-from sys import maxint, stderr
+from sys import maxsize, stderr
 import re
 from libtpcodegen import get_by_path, get_descendant_text, NS_TP, xml_escape
 
@@ -31,14 +31,14 @@ class Xzibit(Exception):
         self.child = child
 
     def __str__(self):
-        print """
+        print("""
     Nested <%s>s are forbidden.
     Parent:
         %s...
     Child:
         %s...
         """ % (self.parent.nodeName, self.parent.toxml()[:100],
-               self.child.toxml()[:100])
+               self.child.toxml()[:100]))
 
 class _QtTypeBinding:
     def __init__(self, val, inarg, outarg, array_val, custom_type, array_of,
@@ -125,8 +125,8 @@ class RefRegistry(object):
             parent = get_closest_parent(ref, 'interface') or get_closest_parent(ref, 'error')
             parent_name = parent.getAttribute('name')
             if (path + parent_name).find('.DRAFT') == -1 and (path + parent_name).find('.FUTURE') == -1:
-                print >> stderr, 'WARNING: Failed to resolve %s to "%s" in "%s"' % (
-                        ref.localName, path, parent_name)
+                print(('WARNING: Failed to resolve %s to "%s" in "%s"' % (
+                        ref.localName, path, parent_name)), file=stderr)
             return path
 
         if ref.localName == 'member-ref':
@@ -166,11 +166,11 @@ def binding_from_usage(sig, tptype, custom_lists, external=False, explicit_own_n
     custom_type = False
     array_of = None
 
-    if natives.has_key(sig):
+    if sig in natives:
         typename, pass_by_ref, array_name = natives[sig]
         val = typename
         inarg = (pass_by_ref and ('const %s&' % val)) or val
-    elif sig[0] == 'a' and natives.has_key(sig[1:]) and natives[sig[1:]][2]:
+    elif sig[0] == 'a' and sig[1:] in natives and natives[sig[1:]][2]:
         val = natives[sig[1:]][2]
         if explicit_own_ns:
             val = explicit_own_ns + '::' + val
@@ -193,7 +193,7 @@ def binding_from_usage(sig, tptype, custom_lists, external=False, explicit_own_n
                 extra_list_nesting += 1
                 tptype = tptype[:-2]
 
-            assert custom_lists.has_key(tptype), ('No array version of custom type %s in the spec, but array version used' % tptype)
+            assert tptype in custom_lists, ('No array version of custom type %s in the spec, but array version used' % tptype)
             val = custom_lists[tptype] + 'List' * extra_list_nesting
         else:
             val = tptype
@@ -282,8 +282,8 @@ def format_docstring(el, refs, indent=' * ', brackets=None, maxwidth=80):
             ref.parentNode.replaceChild(text, ref)
 
         splitted = ''.join([el.toxml() for el in docstring_el.childNodes]).strip(' ').strip('\n').split('\n')
-        level = min([not match and maxint or match.end() - 1 for match in [re.match('^ *[^ ]', line) for line in splitted]])
-        assert level != maxint
+        level = min([not match and maxsize or match.end() - 1 for match in [re.match('^ *[^ ]', line) for line in splitted]])
+        assert level != maxsize
         lines = ['\\htmlonly'] + [line[level:] for line in splitted] + ['\\endhtmlonly']
     else:
         content = xml_escape(get_descendant_text(docstring_el).replace('\n', ' ').strip())
@@ -353,13 +353,13 @@ def gather_custom_lists(spec, typesns):
         if array_depth:
             array_depth = int(array_depth)
         else:
-            array_depth = None
+            array_depth = -1
 
         if array_val:
             custom_lists[tptype] = array_val
             custom_lists[ns + '::' + tptype] = ns + '::' + array_val
             if array_depth >= 2:
-                for i in xrange(array_depth):
+                for i in range(array_depth):
                     custom_lists[tptype + ('[]' * (i+1))] = (
                             array_val + ('List' * i))
                     custom_lists[ns + '::' + tptype + ('[]' * (i+1))] = (
